@@ -251,7 +251,7 @@ void KDirSelectDialog::Private::slotMoveToTrash()
     if (job.askDeleteConfirmation(QList<QUrl>() << url, KIO::JobUiDelegate::Trash, KIO::JobUiDelegate::DefaultConfirmation)) {
         KIO::CopyJob *copyJob = KIO::trash(url);
         KJobWidgets::setWindow(copyJob, m_parent);
-        copyJob->ui()->setAutoErrorHandlingEnabled(true);
+        copyJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
     }
 }
 
@@ -262,7 +262,7 @@ void KDirSelectDialog::Private::slotDelete()
     if (job.askDeleteConfirmation(QList<QUrl>() << url, KIO::JobUiDelegate::Delete, KIO::JobUiDelegate::DefaultConfirmation)) {
         KIO::DeleteJob *deleteJob = KIO::del(url);
         KJobWidgets::setWindow(deleteJob, m_parent);
-        deleteJob->ui()->setAutoErrorHandlingEnabled(true);
+        deleteJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
     }
 }
 
